CropData class

Annotations
  • @HiveType.new(typeId: 6)

Constructors

CropData({required String id, required String name, required String description, required Map<String, WateringSchedule> wateringScheduleByRegion, required int growthDurationDays, String? imageUrl, List<String>? tips})

Properties

box → BoxBase?
Get the box in which this object is stored. Returns null if object has not been added to a box yet.
no setterinherited
description → String
final
growthDurationDays → int
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
imageUrl → String?
final
isInBox → bool
Returns whether this object is currently stored in a box.
no setterinherited
key → dynamic
Get the key associated with this object. Returns null if object has not been added to a box yet.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tips → List<String>?
final
wateringScheduleByRegion → Map<String, WateringSchedule>
final

Methods

delete() → Future<void>
Deletes this object from the box it is stored in.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() → Future<void>
Persists this object.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited